@@ -37,7 +37,7 @@ creating data types.
 
 use strict;
 use Class::Meta::Type;
-our $VERSION = '0.65';
+our $VERSION = '0.66';
 
 sub import {
     my ($pkg, $builder) = @_;
@@ -67,7 +67,7 @@ contribute!
 
 Please file bug reports via L<GitHub
 Issues|http://github.com/theory/class-meta/issues/> or by sending mail to
-L<bug-Class-Meta.cpan.org|mailto:bug-Class-Meta.cpan.org>.
+L<bug-Class-Meta@rt.cpan.org|mailto:bug-Class-Meta@rt.cpan.org>.
 
 =head1 AUTHOR
 
